@@ -6,9 +6,10 @@ from typing import Any, cast, Dict, Optional
 import numpy as np
 import matplotlib.pyplot as plt
 from matplotlib.path import Path
+from matplotlib.figure import Figure
 import networkx as nx
 
-from vivarium.core.process import Process, Factory
+from vivarium.core.process import Process, Composer
 
 
 def construct_storage_path() -> Path:
@@ -101,7 +102,7 @@ def graph_figure(
         buffer: float = 1.0,
         border_width: float = 3,
         label_pos: float = 0.65,
-) -> plt.Figure:
+) -> Figure:
     """ Make a figure from a networkx graph.
 
     :param graph: the networkx.Graph to plot
@@ -264,9 +265,9 @@ class MultiPort(Process):
             'c': {'molecule': 1}}
 
 
-class MergePort(Factory):
+class MergePort(Composer):
     """combines both of MultiPort's ports into one store"""
-    name = 'multi_port_generator'
+    name = 'multi_port_composer'
     defaults = {
         'topology': {
             'multiport1': {
